@@ -8,7 +8,6 @@ our @ISA = qw{ Module::Build };
 
 use Carp;
 
-
 sub ACTION_authortest {
     my ( $self, @args ) = @_;
 
@@ -70,7 +69,9 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https:rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Date-Tolkien-Shire-Data>,
+L<https://github.com/trwyant/perl-Date-Tolkien-Shire-Data/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
